referrerpolicy=no-referrer-when-downgrade

SrcChainConfig

Struct SrcChainConfig 

pub struct SrcChainConfig(/* private fields */);
Configuration for the Polkadot Relay Chain. This should not be used to connect to any other chain; instead use [crate::config::SubstrateConfig] and configure that as needed to support the chain you’re connecting to.

Implementations



impl PolkadotConfig

pub fn new() -> PolkadotConfig

Create a new, default, PolkadotConfig.

pub fn builder() -> PolkadotConfigBuilder

Build a new PolkadotConfig.